# ResearchAI

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

The source code is in `researchai` dir and it was produced by notebooks
in the `nbs` dir by using [nbdev](https://nbdev.fast.ai/).

## Install

``` sh
pip install researchai
```
